pub enum EventTarget {
SocketSelf,
Server,
Socket(SocketID),
Game(GameID),
}Expand description
Target of an event, meant to be used as to property of EventWrapper
Variants
SocketSelf
Specifies the target of the event as the socket that it comes from
This can be used when emitting errors or other private events that the other players should not know about
Server
Specifies the target of the event as the server::GameServer
This can be used when dealing with events that make the server::GameServer do something more than just relay the event
Socket(SocketID)
Specifies the target of the event as another socket::Socket connected to the server::GameServer
This can be used in games where there is a need to privately coordinate
Game(GameID)
Specifies the target of the event as all the socket::Sockets in associated with a GameID
This is the type that will be used most in most games