pub struct Join {
pub game_id: GameID,
pub username: String,
}Expand description
A struct that contains the username of the sender and the GameID of the game that they want to join
This event is used by a socket::Socket to join a game
Fields
game_id: GameIDGameID of the game the game that is to be joined
username: Stringusername of the socket::Socket joining