pub struct Error {
pub reason: String,
}Expand description
A struct that contains a reason field and can be serialized and sent to a client
Fields
reason: StringThe reason the error occurred
Reasons are allowed to be technical, since the users are mostly (if not all) developers and will benefit from error messages that actually say what is wrong, but should also not be too technical, because many users are not experts at rust or programming in general.